Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(484)

Unified Diff: jingle/glue/task_pump.h

Issue 429253003: Webrtc deps roll. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « jingle/glue/mock_task.cc ('k') | jingle/glue/task_pump_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: jingle/glue/task_pump.h
===================================================================
--- jingle/glue/task_pump.h (revision 286889)
+++ jingle/glue/task_pump.h (working copy)
@@ -8,18 +8,18 @@
#include "base/compiler_specific.h"
#include "base/memory/weak_ptr.h"
#include "base/threading/non_thread_safe.h"
-#include "third_party/libjingle/source/talk/base/taskrunner.h"
+#include "third_party/webrtc/base/taskrunner.h"
namespace jingle_glue {
-// talk_base::TaskRunner implementation that works on chromium threads.
-class TaskPump : public talk_base::TaskRunner, public base::NonThreadSafe {
+// rtc::TaskRunner implementation that works on chromium threads.
+class TaskPump : public rtc::TaskRunner, public base::NonThreadSafe {
public:
TaskPump();
virtual ~TaskPump();
- // talk_base::TaskRunner implementation.
+ // rtc::TaskRunner implementation.
virtual void WakeTasks() OVERRIDE;
virtual int64 CurrentTime() OVERRIDE;
« no previous file with comments | « jingle/glue/mock_task.cc ('k') | jingle/glue/task_pump_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698